==> netbeans_6.8.orig.tar.gz: netbeans-6.8/uihandler/src/org/netbeans/modules/uihandler/SlownessData.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.uihandler;

import java.util.logging.Level;
import java.util.logging.LogRecord;

/**
 *
 * @author Jindrich Sedek
 */
class SlownessData {
    private static final String SLOWNESS_DATA = "SlownessData";

    private final long time;
    private final byte[] npsContent;
    private final String latestActionName;

    public SlownessData(long time, byte[] npsContent, String latestActionClassName) {
        this.time = time;
        this.npsContent = npsContent;
        this.latestActionName = latestActionClassName;
    }

    /**
     * @return the time
     */
    public long getTime() {
        return time;
    }

    /**
     * @return the npsContent
     */
    public byte[] getNpsContent() {
        return npsContent;
    }

    public LogRecord getLogRec(){
        LogRecord rec = new LogRecord(Level.CONFIG, SLOWNESS_DATA);
        rec.setParameters(new Object[]{new Long(time), latestActionName});
        return rec;
    }

    /**
     * @return the latestActionClassName
     */
    public String getLatestActionName() {
        return latestActionName;
    }
}

==> netbeans_7.0.1+dfsg1.orig.tar.gz: netbeans-7.0.1+dfsg1/uihandler/src/org/netbeans/modules/uihandler/SlownessData.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */
package org.netbeans.modules.uihandler;

import java.util.logging.Level;
import java.util.logging.LogRecord;

/**
 *
 * @author Jindrich Sedek
 */
class SlownessData {
    private static final String SLOWNESS_DATA = "SlownessData";

    private final long time;
    private final byte[] npsContent;
    private final String latestActionName;
    private final String slownessType;
    
    public SlownessData(long time, byte[] npsContent, String slownessType, String latestActionClassName) {
        this.time = time;
        this.npsContent = npsContent;
        this.slownessType = slownessType;
        this.latestActionName = latestActionClassName;
    }

    /**
     * @return the time
     */
    public long getTime() {
        return time;
    }

    /**
     * @return the npsContent
     */
    public byte[] getNpsContent() {
        return npsContent;
    }

    public LogRecord getLogRec(){
        LogRecord rec = new LogRecord(Level.CONFIG, SLOWNESS_DATA);
        rec.setParameters(new Object[]{new Long(time), latestActionName, slownessType});
        return rec;
    }

    /**
     * @return the latestActionClassName
     */
    public String getLatestActionName() {
        return latestActionName;
    }

    public String getSlownessType() {
        if (slownessType == null){
            return "LowPerformance";
        }
        return slownessType;
    }

}
